==> tfx-cli-0.1.6.tgz: package/exec/build-tasks-upload.js <==
/// <reference path="../../definitions/q/Q.d.ts"/>
/// <reference path="../../definitions/node/node.d.ts"/>
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var cmdm = require('../lib/tfcommand');
var vm = require('../lib/jsonvalidate');
var Q = require('q');
var path = require('path');
var params = require('../lib/parameternames');
var archiver = require('archiver');
var trace = require('../lib/trace');
function describe() {
    return 'upload a build task';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([params.TASK_PATH], []);
}
exports.getArguments = getArguments;
function getCommand() {
    return new BuildTaskUpload();
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = true;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var c_taskJsonFile = 'task.json';
var BuildTaskUpload = (function (_super) {
    __extends(BuildTaskUpload, _super);
    function BuildTaskUpload() {
        _super.apply(this, arguments);
    }
    BuildTaskUpload.prototype.exec = function (args, options) {
        var _this = this;
        trace('build-task-upload.exec');
        var deferred = Q.defer();
        var taskPath = args[0] || options[params.TASK_PATH];
        this.checkRequiredParameter(taskPath, params.TASK_PATH, 'path to the task folder');
        trace('taskPath: ' + taskPath);
        try {
            vm.exists(taskPath, 'specified directory ' + taskPath + ' does not exist.');
        }
        catch (directoryError) {
            deferred.reject(directoryError);
        }
        //directory is good, check json
        var tp = path.resolve(process.cwd(), path.join(taskPath, c_taskJsonFile));
        trace('task.json path: ' + tp);
        vm.validate(tp, 'no ' + c_taskJsonFile + ' in specified directory').then(function (taskJson) {
            var archive = archiver('zip');
            archive.on('error', function (error) {
                trace('Archiving error: ' + error.message);
                error.message = 'Archiving error: ' + error.message;
                deferred.reject(error);
            });
            archive.directory(taskPath, false);
            trace("Initializing agent API...");
            var agentapi = _this.getWebApi().getTaskAgentApi(_this.connection.accountUrl);
            agentapi.uploadTaskDefinition(archive, null, "", taskJson.id, false, function (err, statusCode, task) {
                if (err) {
                    trace('TaskAgentApi.uploadTaskDefinition failed with code ' + statusCode + '. Message: ' + err.message);
                    err.statusCode = statusCode;
                    deferred.reject(err);
                }
                else {
                    trace('Success');
                    deferred.resolve({
                        sourceLocation: taskPath
                    });
                }
            });
            archive.finalize();
        }).fail(function (error) {
            trace('Task json validation failed.');
            deferred.reject(error);
        });
        return deferred.promise;
    };
    BuildTaskUpload.prototype.output = function (data) {
        console.log('task at: ' + data.sourceLocation + ' uploaded successfully!');
    };
    return BuildTaskUpload;
})(cmdm.TfCommand);
exports.BuildTaskUpload = BuildTaskUpload;

==> tfx-cli-0.1.7.tgz: package/exec/build-tasks-upload.js <==
/// <reference path="../../definitions/q/Q.d.ts"/>
/// <reference path="../../definitions/node/node.d.ts"/>
var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var cmdm = require('../lib/tfcommand');
var vm = require('../lib/jsonvalidate');
var Q = require('q');
var path = require('path');
var params = require('../lib/parameternames');
var archiver = require('archiver');
var trace = require('../lib/trace');
function describe() {
    return 'upload a build task';
}
exports.describe = describe;
function getArguments() {
    return cmdm.formatArgumentsHint([params.TASK_PATH], []);
}
exports.getArguments = getArguments;
function getCommand() {
    return new BuildTaskUpload();
}
exports.getCommand = getCommand;
// requires auth, connect etc...
exports.isServerOperation = true;
// unless you have a good reason, should not hide
exports.hideBanner = false;
var c_taskJsonFile = 'task.json';
var BuildTaskUpload = (function (_super) {
    __extends(BuildTaskUpload, _super);
    function BuildTaskUpload() {
        _super.apply(this, arguments);
    }
    BuildTaskUpload.prototype.exec = function (args, options) {
        var _this = this;
        trace('build-task-upload.exec');
        var deferred = Q.defer();
        var taskPath = args[0] || options[params.TASK_PATH];
        this.checkRequiredParameter(taskPath, params.TASK_PATH, 'path to the task folder');
        trace('taskPath: ' + taskPath);
        try {
            vm.exists(taskPath, 'specified directory ' + taskPath + ' does not exist.');
        }
        catch (directoryError) {
            deferred.reject(directoryError);
        }
        //directory is good, check json
        var tp = path.resolve(process.cwd(), path.join(taskPath, c_taskJsonFile));
        trace('task.json path: ' + tp);
        vm.validate(tp, 'no ' + c_taskJsonFile + ' in specified directory').then(function (taskJson) {
            var archive = archiver('zip');
            archive.on('error', function (error) {
                trace('Archiving error: ' + error.message);
                error.message = 'Archiving error: ' + error.message;
                deferred.reject(error);
            });
            archive.directory(taskPath, false);
            trace("Initializing agent API...");
            var agentapi = _this.getWebApi().getTaskAgentApi(_this.connection.accountUrl);
            agentapi.uploadTaskDefinition(null, archive, taskJson.id, false, function (err, statusCode, task) {
                if (err) {
                    trace('TaskAgentApi.uploadTaskDefinition failed with code ' + statusCode + '. Message: ' + err.message);
                    err.statusCode = statusCode;
                    deferred.reject(err);
                }
                else {
                    trace('Success');
                    deferred.resolve({
                        sourceLocation: taskPath
                    });
                }
            });
            archive.finalize();
        }).fail(function (error) {
            trace('Task json validation failed.');
            deferred.reject(error);
        });
        return deferred.promise;
    };
    BuildTaskUpload.prototype.output = function (data) {
        console.log('task at: ' + data.sourceLocation + ' uploaded successfully!');
    };
    return BuildTaskUpload;
})(cmdm.TfCommand);
exports.BuildTaskUpload = BuildTaskUpload;
